@@ -21,8 +21,6 @@ class Events(StreamingAPI):
         else:
             url = "/".join([dockercloud.stream_host.rstrip("/"), "api", "audit", self._api_version,
                             endpoint.lstrip("/")])
-        self.invaid_auth_headers = set()
-        self.auth_error = ""
         super(self.__class__, self).__init__(url)
 
     def _on_message(self, ws, message):
@@ -39,15 +37,16 @@ class Events(StreamingAPI):
 
     def _on_error(self, ws, e):
         if isinstance(e, websocket._exceptions.WebSocketBadStatusException) and getattr(e, "status_code") == 401:
-            self.auth_error = "Not Authorized"
-            self.invaid_auth_headers.add(str(dockercloud.auth.get_auth_header()))
+            self.auth_error = True
 
         super(self.__class__, self)._on_error(ws, e)
 
     def run_forever(self, *args, **kwargs):
         while True:
-            if str(dockercloud.auth.get_auth_header()) in self.invaid_auth_headers:
-                raise AuthError(self.auth_error)
+            if self.auth_error:
+                self.auth_error = False
+                raise AuthError("Not Authorized")
+
             ws = websocket.WebSocketApp(self.url, header=self.header,
                                         on_open=self._on_open,
                                         on_message=self._on_message,
